pub fn keypair(n: usize) -> KeypairExpand description
Returns a recognisable Keypair / wallet that can be used for the mint account for example. The public key will
start with Txxx, where xxx are the three digits of the number. You shouldn’t call the method with the same n
twice. o is used instead of 0, as 0 is not part of the base58 charset.
The n must be a number between 0 and 255.